summaryrefslogtreecommitdiffstats
path: root/kregexpeditor
diff options
context:
space:
mode:
Diffstat (limited to 'kregexpeditor')
-rw-r--r--kregexpeditor/Comments2
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp4
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.h4
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.cpp4
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.h2
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistbox.cpp4
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistbox.h4
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h2
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.cpp4
-rw-r--r--kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.h8
-rw-r--r--kregexpeditor/altnwidget.cpp10
-rw-r--r--kregexpeditor/altnwidget.h4
-rw-r--r--kregexpeditor/auxbuttons.cpp4
-rw-r--r--kregexpeditor/auxbuttons.h2
-rw-r--r--kregexpeditor/characterswidget.cpp22
-rw-r--r--kregexpeditor/characterswidget.h14
-rw-r--r--kregexpeditor/charselector.cpp6
-rw-r--r--kregexpeditor/charselector.h2
-rw-r--r--kregexpeditor/compoundwidget.cpp12
-rw-r--r--kregexpeditor/compoundwidget.h6
-rw-r--r--kregexpeditor/concwidget.cpp12
-rw-r--r--kregexpeditor/concwidget.h6
-rw-r--r--kregexpeditor/dcbutton.cpp4
-rw-r--r--kregexpeditor/dcbutton.h2
-rw-r--r--kregexpeditor/drag.cpp4
-rw-r--r--kregexpeditor/drag.h2
-rw-r--r--kregexpeditor/dragaccepter.cpp16
-rw-r--r--kregexpeditor/dragaccepter.h2
-rw-r--r--kregexpeditor/editorwindow.cpp4
-rw-r--r--kregexpeditor/editorwindow.h2
-rw-r--r--kregexpeditor/infopage.cpp4
-rw-r--r--kregexpeditor/infopage.h2
-rw-r--r--kregexpeditor/kregexpeditorgui.cpp8
-rw-r--r--kregexpeditor/kregexpeditorgui.h4
-rw-r--r--kregexpeditor/kregexpeditorprivate.cpp4
-rw-r--r--kregexpeditor/kregexpeditorprivate.h2
-rw-r--r--kregexpeditor/limitedcharlineedit.cpp8
-rw-r--r--kregexpeditor/limitedcharlineedit.h2
-rw-r--r--kregexpeditor/lookaheadwidget.cpp8
-rw-r--r--kregexpeditor/lookaheadwidget.h4
-rw-r--r--kregexpeditor/multicontainerwidget.cpp6
-rw-r--r--kregexpeditor/multicontainerwidget.h2
-rw-r--r--kregexpeditor/qt-only/compat.cpp20
-rw-r--r--kregexpeditor/qt-only/compat.h10
-rw-r--r--kregexpeditor/regexp.cpp4
-rw-r--r--kregexpeditor/regexp.h2
-rw-r--r--kregexpeditor/regexpbuttons.cpp4
-rw-r--r--kregexpeditor/regexpbuttons.h2
-rw-r--r--kregexpeditor/regexpwidget.cpp6
-rw-r--r--kregexpeditor/regexpwidget.h6
-rw-r--r--kregexpeditor/repeatwidget.cpp20
-rw-r--r--kregexpeditor/repeatwidget.h8
-rw-r--r--kregexpeditor/scrollededitorwindow.cpp4
-rw-r--r--kregexpeditor/scrollededitorwindow.h2
-rw-r--r--kregexpeditor/selectablelineedit.cpp4
-rw-r--r--kregexpeditor/selectablelineedit.h2
-rw-r--r--kregexpeditor/singlecontainerwidget.cpp4
-rw-r--r--kregexpeditor/singlecontainerwidget.h2
-rw-r--r--kregexpeditor/textwidget.cpp16
-rw-r--r--kregexpeditor/textwidget.h4
-rw-r--r--kregexpeditor/userdefinedregexps.cpp8
-rw-r--r--kregexpeditor/userdefinedregexps.h4
-rw-r--r--kregexpeditor/verifier.cpp2
-rw-r--r--kregexpeditor/verifier.h2
-rw-r--r--kregexpeditor/verifybuttons.cpp4
-rw-r--r--kregexpeditor/verifybuttons.h2
-rw-r--r--kregexpeditor/widgetfactory.cpp52
-rw-r--r--kregexpeditor/widgetfactory.h4
-rw-r--r--kregexpeditor/zerowidgets.cpp24
-rw-r--r--kregexpeditor/zerowidgets.h12
70 files changed, 231 insertions, 231 deletions
diff --git a/kregexpeditor/Comments b/kregexpeditor/Comments
index e9fc09d..97cd98e 100644
--- a/kregexpeditor/Comments
+++ b/kregexpeditor/Comments
@@ -1,4 +1,4 @@
(1) If I do not resize the widget to be reparented then it will take up all
- the size of its new tqparent, and the tqparent will never receive a
+ the size of its new parent, and the parent will never receive a
tqrepaint event, and will thus never get a chance to resize its new child
to a proper size (This is namely done in repaintEvent() ).
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp
index ba37b73..6e82e85 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.cpp
@@ -38,8 +38,8 @@ const uchar indexButtonBits[] = {
};
-KMultiFormListBoxMultiVisible::KMultiFormListBoxMultiVisible(KMultiFormListBoxFactory *fact, TQWidget *tqparent, const char *name)
- : TQScrollView(tqparent, name)
+KMultiFormListBoxMultiVisible::KMultiFormListBoxMultiVisible(KMultiFormListBoxFactory *fact, TQWidget *parent, const char *name)
+ : TQScrollView(parent, name)
{
factory = fact;
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.h b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.h
index f0e5d79..172bb6f 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.h
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-multivisible.h
@@ -43,9 +43,9 @@ private:
/**
@param factory A factory used to generate the instances of KMultiFormListBoxEntry
class which is repeated in the KMultiFormListBox
- @param tqparent A pointer to the tqparent widget
+ @param parent A pointer to the parent widget
*/
- KMultiFormListBoxMultiVisible(KMultiFormListBoxFactory *factory, TQWidget *tqparent = 0, const char *name = 0);
+ KMultiFormListBoxMultiVisible(KMultiFormListBoxFactory *factory, TQWidget *parent = 0, const char *name = 0);
/**
@return The elements in the KMultiFormListBox
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.cpp b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.cpp
index 6f9246c..905634c 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.cpp
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.cpp
@@ -27,10 +27,10 @@
#include "widgetwindow.h"
#include "windowlistboxitem.h"
-KMultiFormListBoxWindowed::KMultiFormListBoxWindowed(KMultiFormListBoxFactory *factory, TQWidget *tqparent,
+KMultiFormListBoxWindowed::KMultiFormListBoxWindowed(KMultiFormListBoxFactory *factory, TQWidget *parent,
bool showUpDownButtons, bool showHelpButton,
TQString addButtonText,const char *name)
- : TQWidget( tqparent, name )
+ : TQWidget( parent, name )
{
_layout = new TQVBoxLayout(this);
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.h b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.h
index ca3f8bf..764993e 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.h
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistbox-windowed.h
@@ -43,7 +43,7 @@ Q_OBJECT
friend class KMultiFormListBox;
private:
- KMultiFormListBoxWindowed(KMultiFormListBoxFactory *factory, TQWidget *tqparent,
+ KMultiFormListBoxWindowed(KMultiFormListBoxFactory *factory, TQWidget *parent,
bool showUpDownButtons, bool showHelpButton, TQString addButtonText,
const char *name);
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistbox.cpp b/kregexpeditor/KMultiFormListBox/kmultiformlistbox.cpp
index 8ddb5c7..a455bae 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistbox.cpp
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistbox.cpp
@@ -22,9 +22,9 @@
#include "kmultiformlistbox-multivisible.h"
#include "kmultiformlistbox-windowed.h"
-KMultiFormListBox::KMultiFormListBox( KMultiFormListBoxFactory *factory, KMultiFormListBoxType tp, TQWidget *tqparent,
+KMultiFormListBox::KMultiFormListBox( KMultiFormListBoxFactory *factory, KMultiFormListBoxType tp, TQWidget *parent,
bool showUpDownButtons, bool showHelpButton, TQString addButtonText,
- const char *name ) : TQWidget( tqparent, name )
+ const char *name ) : TQWidget( parent, name )
{
switch ( tp ) {
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistbox.h b/kregexpeditor/KMultiFormListBox/kmultiformlistbox.h
index 0a23863..ba9b8a8 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistbox.h
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistbox.h
@@ -72,11 +72,11 @@ public:
/**
@param factory A factory used to generate the instances of
KMultiFormListBoxEntry class which is repeated in the KMultiFormListBox
- @param tqparent A pointer to the tqparent widget
+ @param parent A pointer to the parent widget
**/
KMultiFormListBox(KMultiFormListBoxFactory *factory,
KMultiFormListBoxType tp=Windowed,
- TQWidget *tqparent = 0, bool showUpDownButtons = true,
+ TQWidget *parent = 0, bool showUpDownButtons = true,
bool showHelpButton = true, TQString addButtonText = i18n("Add"),
const char *name = 0);
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h b/kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h
index c51ac16..b4bf36c 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistboxentry.h
@@ -51,7 +51,7 @@ class KMultiFormListBoxEntry : public TQWidget
TQ_OBJECT
public:
- KMultiFormListBoxEntry(TQWidget *tqparent, const char *name) : TQWidget(tqparent,name) {}
+ KMultiFormListBoxEntry(TQWidget *parent, const char *name) : TQWidget(parent,name) {}
virtual TQPushButton *indexButton() { return 0; }
virtual TQWidget *valueWidget() { return 0; }
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.cpp b/kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.cpp
index 8432ccf..08a800a 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.cpp
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.cpp
@@ -18,8 +18,8 @@
#include "kmultiformlistboxfactory.h"
#include <tqframe.h>
-TQWidget *KMultiFormListBoxFactory::separator(TQWidget *tqparent) {
- TQFrame* sep = new TQFrame( tqparent );
+TQWidget *KMultiFormListBoxFactory::separator(TQWidget *parent) {
+ TQFrame* sep = new TQFrame( parent );
sep->setFrameStyle( TQFrame::HLine | TQFrame::Sunken);
sep->setLineWidth(1);
return sep;
diff --git a/kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.h b/kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.h
index 61a78aa..dc0bcce 100644
--- a/kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.h
+++ b/kregexpeditor/KMultiFormListBox/kmultiformlistboxfactory.h
@@ -47,23 +47,23 @@ public:
a subclass of this class. This instance will be owned by the caller of
this function.
- @param tqparent A pointer to the tqparent of this KMultiFormListBoxEntry widget
+ @param parent A pointer to the parent of this KMultiFormListBoxEntry widget
returned.
@return A fresh @ref KMultiFormListBoxEntry to be used in an instance of the
@ref KMultiFormListBox class.
**/
- virtual KMultiFormListBoxEntry *create(TQWidget *tqparent) = 0;
+ virtual KMultiFormListBoxEntry *create(TQWidget *parent) = 0;
/**
This method is used to get a separator between the elements in an @ref
KMultiFormListBox. The widget returned from this method will be owned by the
caller.
- @param tqparent A pointer to the tqparent of the TQWidget returned.
+ @param parent A pointer to the parent of the TQWidget returned.
@return A widget which must be used as a separator between the @ref
KMultiFormListBoxEntry elements in an @ref KMultiFormListBox.
**/
- virtual TQWidget *separator(TQWidget *tqparent);
+ virtual TQWidget *separator(TQWidget *parent);
};
#endif /* kmultiformlistbox */
diff --git a/kregexpeditor/altnwidget.cpp b/kregexpeditor/altnwidget.cpp
index ae13e43..25befe5 100644
--- a/kregexpeditor/altnwidget.cpp
+++ b/kregexpeditor/altnwidget.cpp
@@ -28,9 +28,9 @@
#include "altnregexp.h"
#include <tqpainter.h>
-AltnWidget::AltnWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+AltnWidget::AltnWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- :MultiContainerWidget(editorWindow, tqparent, name == 0 ? "AltnWidget" : name)
+ :MultiContainerWidget(editorWindow, parent, name == 0 ? "AltnWidget" : name)
{
DragAccepter *accepter = new DragAccepter(editorWindow, this);
accepter->resize(0,0); // See note (1) in Comments
@@ -39,8 +39,8 @@ AltnWidget::AltnWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
}
AltnWidget::AltnWidget( AltnRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name)
- :MultiContainerWidget( editorWindow, tqparent, name )
+ TQWidget* parent, const char* name)
+ :MultiContainerWidget( editorWindow, parent, name )
{
DragAccepter *accepter = new DragAccepter(editorWindow, this);
accepter->resize(0,0); // See note (1) in Comments
@@ -52,7 +52,7 @@ AltnWidget::AltnWidget( AltnRegExp* regexp, RegExpEditorWindow* editorWindow,
RegExpWidget* child = WidgetFactory::createWidget( *it, editorWindow, this );
ConcWidget* conc;
if ( ! (conc = dynamic_cast<ConcWidget*>( child ) ) ) {
- conc = new ConcWidget( editorWindow, child, tqparent );
+ conc = new ConcWidget( editorWindow, child, parent );
}
append( conc );
}
diff --git a/kregexpeditor/altnwidget.h b/kregexpeditor/altnwidget.h
index 8b76a66..519eba5 100644
--- a/kregexpeditor/altnwidget.h
+++ b/kregexpeditor/altnwidget.h
@@ -29,10 +29,10 @@ class AltnRegExp;
class AltnWidget :public MultiContainerWidget
{
public:
- AltnWidget( RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ AltnWidget( RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *label = 0);
AltnWidget( AltnRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name = 0);
+ TQWidget* parent, const char* name = 0);
virtual void addNewChild(DragAccepter *accepter, RegExpWidget *child);
virtual TQSize tqsizeHint() const;
virtual RegExp* regExp() const;
diff --git a/kregexpeditor/auxbuttons.cpp b/kregexpeditor/auxbuttons.cpp
index d22d229..855f6d1 100644
--- a/kregexpeditor/auxbuttons.cpp
+++ b/kregexpeditor/auxbuttons.cpp
@@ -32,8 +32,8 @@
#include <tqtoolbutton.h>
#include "util.h"
-AuxButtons::AuxButtons( TQWidget* tqparent, const char* name = 0)
- :TQDockWindow( TQDockWindow::InDock, tqparent, name)
+AuxButtons::AuxButtons( TQWidget* parent, const char* name = 0)
+ :TQDockWindow( TQDockWindow::InDock, parent, name)
{
TQBoxLayout* tqlayout = boxLayout();
diff --git a/kregexpeditor/auxbuttons.h b/kregexpeditor/auxbuttons.h
index a0ada03..d16b7c7 100644
--- a/kregexpeditor/auxbuttons.h
+++ b/kregexpeditor/auxbuttons.h
@@ -29,7 +29,7 @@ class AuxButtons :public TQDockWindow
TQ_OBJECT
public:
- AuxButtons( TQWidget* tqparent, const char* name );
+ AuxButtons( TQWidget* parent, const char* name );
signals:
void undo();
diff --git a/kregexpeditor/characterswidget.h b/kregexpeditor/characterswidget.h
index f8cf390..ccc8852 100644
--- a/kregexpeditor/characterswidget.h
+++ b/kregexpeditor/characterswidget.h
@@ -41,10 +41,10 @@ class TQCheckBox;
class CharactersWidget :public RegExpWidget
{
public:
- CharactersWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ CharactersWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *label = 0);
CharactersWidget( TextRangeRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name = 0 );
+ TQWidget* parent, const char* name = 0 );
~CharactersWidget();
virtual TQSize tqsizeHint() const;
virtual RegExp* regExp() const;
@@ -72,7 +72,7 @@ private:
class SingleEntry :public KMultiFormListBoxEntry
{
public:
- SingleEntry(TQWidget* tqparent, const char* name = 0 );
+ SingleEntry(TQWidget* parent, const char* name = 0 );
TQString text() const;
void setText( TQString text );
bool isEmpty() const;
@@ -87,7 +87,7 @@ private:
class RangeEntry :public KMultiFormListBoxEntry
{
public:
- RangeEntry(TQWidget* tqparent, const char* name = 0 );
+ RangeEntry(TQWidget* parent, const char* name = 0 );
TQString fromText() const;
TQString toText() const;
void setFrom( TQString text );
@@ -103,7 +103,7 @@ private:
class SingleFactory :public KMultiFormListBoxFactory
{
public:
- KMultiFormListBoxEntry *create(TQWidget *tqparent) { return new SingleEntry( tqparent ); }
+ KMultiFormListBoxEntry *create(TQWidget *parent) { return new SingleEntry( parent ); }
TQWidget *separator( TQWidget* ) { return 0; }
};
@@ -113,7 +113,7 @@ public:
class RangeFactory :public KMultiFormListBoxFactory
{
public:
- KMultiFormListBoxEntry *create(TQWidget *tqparent) { return new RangeEntry( tqparent ); }
+ KMultiFormListBoxEntry *create(TQWidget *parent) { return new RangeEntry( parent ); }
TQWidget *separator( TQWidget* ) { return 0; }
};
@@ -125,7 +125,7 @@ class CharacterEdits : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- CharacterEdits(TQWidget *tqparent = 0, const char *name = 0);
+ CharacterEdits(TQWidget *parent = 0, const char *name = 0);
public slots:
int exec( TextRangeRegExp* regexp );
diff --git a/kregexpeditor/charselector.cpp b/kregexpeditor/charselector.cpp
index d5f0a07..5f60475 100644
--- a/kregexpeditor/charselector.cpp
+++ b/kregexpeditor/charselector.cpp
@@ -41,7 +41,7 @@
class StackContainer :public TQWidget
{
public:
- StackContainer( TQWidget* child, TQWidget* tqparent ) : TQWidget( tqparent )
+ StackContainer( TQWidget* child, TQWidget* parent ) : TQWidget( parent )
{
TQHBoxLayout* tqlayout = new TQHBoxLayout( this );
child->reparent( this, TQPoint(0,0), false );
@@ -50,8 +50,8 @@ public:
}
};
-CharSelector::CharSelector( TQWidget* tqparent, const char* name )
- :TQWidget( tqparent, name ), _oldIndex(0)
+CharSelector::CharSelector( TQWidget* parent, const char* name )
+ :TQWidget( parent, name ), _oldIndex(0)
{
TQStringList items;
TQHBoxLayout* tqlayout = new TQHBoxLayout( this, 0, 6 );
diff --git a/kregexpeditor/charselector.h b/kregexpeditor/charselector.h
index 5ba2a88..c34ffac 100644
--- a/kregexpeditor/charselector.h
+++ b/kregexpeditor/charselector.h
@@ -30,7 +30,7 @@ class CharSelector :public TQWidget
TQ_OBJECT
public:
- CharSelector( TQWidget* tqparent, const char* name = 0 );
+ CharSelector( TQWidget* parent, const char* name = 0 );
TQString text() const;
void setText( TQString text );
bool isEmpty() const;
diff --git a/kregexpeditor/compoundwidget.cpp b/kregexpeditor/compoundwidget.cpp
index 00c484c..c43dcbb 100644
--- a/kregexpeditor/compoundwidget.cpp
+++ b/kregexpeditor/compoundwidget.cpp
@@ -37,8 +37,8 @@
//================================================================================
-CompoundDetailWindow::CompoundDetailWindow( TQWidget* tqparent, const char* name )
- :TQWidget( tqparent, name )
+CompoundDetailWindow::CompoundDetailWindow( TQWidget* parent, const char* name )
+ :TQWidget( parent, name )
{
TQVBoxLayout* tqlayout = new TQVBoxLayout( this );
tqlayout->setAutoAdd( true );
@@ -93,17 +93,17 @@ void CompoundDetailWindow::setAllowReplace( bool b )
//================================================================================
-CompoundWidget::CompoundWidget( RegExpEditorWindow* editorWindow, TQWidget* tqparent,
+CompoundWidget::CompoundWidget( RegExpEditorWindow* editorWindow, TQWidget* parent,
const char* name )
- :SingleContainerWidget( editorWindow, tqparent, name == 0 ? "CompoundWidget" : name )
+ :SingleContainerWidget( editorWindow, parent, name == 0 ? "CompoundWidget" : name )
{
_child = new ConcWidget( editorWindow, this );
init();
}
CompoundWidget::CompoundWidget( CompoundRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name )
- : SingleContainerWidget( editorWindow, tqparent, name == 0 ? "CompoundWidget" : name )
+ TQWidget* parent, const char* name )
+ : SingleContainerWidget( editorWindow, parent, name == 0 ? "CompoundWidget" : name )
{
init();
_content->setTitle( regexp->title() );
diff --git a/kregexpeditor/compoundwidget.h b/kregexpeditor/compoundwidget.h
index 8a803a3..047f942 100644
--- a/kregexpeditor/compoundwidget.h
+++ b/kregexpeditor/compoundwidget.h
@@ -32,7 +32,7 @@ class TQCheckBox;
class CompoundDetailWindow :public TQWidget
{
public:
- CompoundDetailWindow(TQWidget* tqparent, const char* name = 0);
+ CompoundDetailWindow(TQWidget* parent, const char* name = 0);
TQString title() const;
TQString description() const;
bool allowReplace() const;
@@ -63,10 +63,10 @@ Q_OBJECT
TQ_OBJECT
public:
- CompoundWidget( RegExpEditorWindow* editorWindow, TQWidget* tqparent,
+ CompoundWidget( RegExpEditorWindow* editorWindow, TQWidget* parent,
const char* name = 0);
CompoundWidget( CompoundRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name = 0);
+ TQWidget* parent, const char* name = 0);
virtual bool updateSelection( bool parentSelected );
virtual TQSize tqsizeHint() const;
diff --git a/kregexpeditor/concwidget.cpp b/kregexpeditor/concwidget.cpp
index d70e735..16690be 100644
--- a/kregexpeditor/concwidget.cpp
+++ b/kregexpeditor/concwidget.cpp
@@ -21,9 +21,9 @@
#include <tqpainter.h>
-ConcWidget::ConcWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ConcWidget::ConcWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- :MultiContainerWidget(editorWindow, tqparent, name == 0 ? "concwidget" : name)
+ :MultiContainerWidget(editorWindow, parent, name == 0 ? "concwidget" : name)
{
init();
DragAccepter *accepter = new DragAccepter(editorWindow, this);
@@ -33,8 +33,8 @@ ConcWidget::ConcWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
ConcWidget::ConcWidget(RegExpEditorWindow* editorWindow, RegExpWidget *child,
- TQWidget *tqparent, const char *name)
- :MultiContainerWidget(editorWindow, tqparent, name == 0 ? "concwidget" : name)
+ TQWidget *parent, const char *name)
+ :MultiContainerWidget(editorWindow, parent, name == 0 ? "concwidget" : name)
{
init();
DragAccepter *accepter = new DragAccepter(editorWindow, this);
@@ -58,8 +58,8 @@ ConcWidget::ConcWidget( RegExpEditorWindow* editorWindow, ConcWidget* origConc,
}
ConcWidget::ConcWidget( ConcRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name )
- :MultiContainerWidget( editorWindow, tqparent, name == 0 ? "concwidget" : name )
+ TQWidget* parent, const char* name )
+ :MultiContainerWidget( editorWindow, parent, name == 0 ? "concwidget" : name )
{
init();
DragAccepter *accepter = new DragAccepter(editorWindow, this);
diff --git a/kregexpeditor/concwidget.h b/kregexpeditor/concwidget.h
index 49f6308..bff85a7 100644
--- a/kregexpeditor/concwidget.h
+++ b/kregexpeditor/concwidget.h
@@ -30,14 +30,14 @@ class ConcRegExp;
class ConcWidget :public MultiContainerWidget
{
public:
- ConcWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ ConcWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name = 0);
ConcWidget(RegExpEditorWindow* editorWindow, RegExpWidget *child,
- TQWidget *tqparent, const char *name=0);
+ TQWidget *parent, const char *name=0);
ConcWidget( RegExpEditorWindow* editorWindow, ConcWidget* origConc,
unsigned int start, unsigned int end);
ConcWidget( ConcRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name = 0);
+ TQWidget* parent, const char* name = 0);
void init();
virtual TQSize tqsizeHint() const;
diff --git a/kregexpeditor/dcbutton.cpp b/kregexpeditor/dcbutton.cpp
index 770b101..754b305 100644
--- a/kregexpeditor/dcbutton.cpp
+++ b/kregexpeditor/dcbutton.cpp
@@ -23,8 +23,8 @@
#include "dcbutton.h"
-DoubleClickButton::DoubleClickButton( TQPixmap pixmap, TQWidget* tqparent, const char* name )
- : TQToolButton( tqparent, name ? name : "DoubleClickButton" )
+DoubleClickButton::DoubleClickButton( TQPixmap pixmap, TQWidget* parent, const char* name )
+ : TQToolButton( parent, name ? name : "DoubleClickButton" )
{
setPixmap( pixmap );
}
diff --git a/kregexpeditor/dcbutton.h b/kregexpeditor/dcbutton.h
index 0bdd2ca..8f56505 100644
--- a/kregexpeditor/dcbutton.h
+++ b/kregexpeditor/dcbutton.h
@@ -31,7 +31,7 @@ Q_OBJECT
TQ_OBJECT
public:
- DoubleClickButton( TQPixmap pix, TQWidget* tqparent, const char* name = 0);
+ DoubleClickButton( TQPixmap pix, TQWidget* parent, const char* name = 0);
protected:
virtual void mouseDoubleClickEvent ( TQMouseEvent * );
diff --git a/kregexpeditor/drag.cpp b/kregexpeditor/drag.cpp
index 51197a4..9c2b1ca 100644
--- a/kregexpeditor/drag.cpp
+++ b/kregexpeditor/drag.cpp
@@ -37,13 +37,13 @@ bool RegExpWidgetDrag::canDecode( TQDragMoveEvent* event )
}
RegExpWidget* RegExpWidgetDrag::decode(TQDropEvent* event, RegExpEditorWindow* window,
- TQWidget* tqparent)
+ TQWidget* parent)
{
TQByteArray payload = event->tqencodedData("KRegExpEditor/widgetdrag" );
TQTextStream stream( payload, IO_ReadOnly );
TQString str = stream.read();
RegExp* regexp = WidgetFactory::createRegExp( str );
- RegExpWidget* widget = WidgetFactory::createWidget( regexp, window, tqparent );
+ RegExpWidget* widget = WidgetFactory::createWidget( regexp, window, parent );
delete regexp;
return widget;
}
diff --git a/kregexpeditor/drag.h b/kregexpeditor/drag.h
index 7173444..699d1e8 100644
--- a/kregexpeditor/drag.h
+++ b/kregexpeditor/drag.h
@@ -37,7 +37,7 @@ public:
virtual TQByteArray tqencodedData ( const char * ) const;
static bool canDecode(TQDragMoveEvent* event);
static RegExpWidget* decode(TQDropEvent* event, RegExpEditorWindow* window,
- TQWidget* tqparent);
+ TQWidget* parent);
private:
RegExp* _regexp;
};
diff --git a/kregexpeditor/dragaccepter.h b/kregexpeditor/dragaccepter.h
index cead17f..a3737d9 100644
--- a/kregexpeditor/dragaccepter.h
+++ b/kregexpeditor/dragaccepter.h
@@ -30,7 +30,7 @@ class DragAccepter :public RegExpWidget
friend class MultiContainerWidget;
public:
- DragAccepter(RegExpEditorWindow* editorWindow, RegExpWidget *tqparent,
+ DragAccepter(RegExpEditorWindow* editorWindow, RegExpWidget *parent,
const char *name = 0);
TQSize tqsizeHint() const;
virtual RegExp* regExp() const;
diff --git a/kregexpeditor/editorwindow.cpp b/kregexpeditor/editorwindow.cpp
index 8b87998..8e3cc20 100644
--- a/kregexpeditor/editorwindow.cpp
+++ b/kregexpeditor/editorwindow.cpp
@@ -41,8 +41,8 @@
#include "userdefinedregexps.h"
#include <tqfileinfo.h>
-RegExpEditorWindow::RegExpEditorWindow( TQWidget *tqparent, const char *name)
- : TQWidget(tqparent, name, TQt::WPaintUnclipped)
+RegExpEditorWindow::RegExpEditorWindow( TQWidget *parent, const char *name)
+ : TQWidget(parent, name, TQt::WPaintUnclipped)
{
_top = new ConcWidget(this, this);
_layout = new TQHBoxLayout( this);
diff --git a/kregexpeditor/editorwindow.h b/kregexpeditor/editorwindow.h
index f1484f1..58377c6 100644
--- a/kregexpeditor/editorwindow.h
+++ b/kregexpeditor/editorwindow.h
@@ -49,7 +49,7 @@ class RegExpEditorWindow :public TQWidget
TQ_OBJECT
public:
- RegExpEditorWindow(TQWidget *tqparent, const char *name = 0);
+ RegExpEditorWindow(TQWidget *parent, const char *name = 0);
/**
Returns an object which represent the regular expression "drawn" in
diff --git a/kregexpeditor/infopage.cpp b/kregexpeditor/infopage.cpp
index 90ff202..42d473e 100644
--- a/kregexpeditor/infopage.cpp
+++ b/kregexpeditor/infopage.cpp
@@ -24,8 +24,8 @@
#include "infopage.h"
-InfoPage::InfoPage( TQWidget* tqparent, const char* name )
- :KTextBrowser( tqparent, name )
+InfoPage::InfoPage( TQWidget* parent, const char* name )
+ :KTextBrowser( parent, name )
{
TQString txt =
TQString::tqfromLatin1( "<qt>" ) +
diff --git a/kregexpeditor/infopage.h b/kregexpeditor/infopage.h
index 6367cda..24796d2 100644
--- a/kregexpeditor/infopage.h
+++ b/kregexpeditor/infopage.h
@@ -28,7 +28,7 @@
class InfoPage :public KTextBrowser
{
public:
- InfoPage( TQWidget* tqparent, const char* name );
+ InfoPage( TQWidget* parent, const char* name );
virtual void setSource ( const TQString& name );
};
diff --git a/kregexpeditor/kregexpeditorgui.cpp b/kregexpeditor/kregexpeditorgui.cpp
index 11a0264..95c0f25 100644
--- a/kregexpeditor/kregexpeditorgui.cpp
+++ b/kregexpeditor/kregexpeditorgui.cpp
@@ -34,9 +34,9 @@
const TQString KRegExpEditorGUI::version = TQString::fromLocal8Bit("1.0");
-KRegExpEditorGUI::KRegExpEditorGUI(TQWidget *tqparent, const char *name,
+KRegExpEditorGUI::KRegExpEditorGUI(TQWidget *parent, const char *name,
const TQStringList & )
- : TQWidget( tqparent, name)
+ : TQWidget( parent, name)
{
TQHBoxLayout* tqlayout = new TQHBoxLayout( this, 6 );
_editor = new KRegExpEditorPrivate( this, "_editor" );
@@ -66,12 +66,12 @@ void KRegExpEditorGUI::setRegExp( const TQString &regexp )
_editor->slotSetRegexp( regexp );
}
-KRegExpEditorGUIDialog::KRegExpEditorGUIDialog( TQWidget *tqparent,
+KRegExpEditorGUIDialog::KRegExpEditorGUIDialog( TQWidget *parent,
const char *name,
const TQStringList & )
: KDialogBase( KDialogBase::Plain, i18n("Regular Expression Editor"),
KDialogBase::Ok | KDialogBase::Cancel | KDialogBase::Help, KDialogBase::Ok,
- tqparent, name ? name : "KRegExpDialog" )
+ parent, name ? name : "KRegExpDialog" )
{
TQFrame* frame = plainPage();
TQVBoxLayout* tqlayout = new TQVBoxLayout( frame, 6 );
diff --git a/kregexpeditor/kregexpeditorgui.h b/kregexpeditor/kregexpeditorgui.h
index 96eb234..58ecc65 100644
--- a/kregexpeditor/kregexpeditorgui.h
+++ b/kregexpeditor/kregexpeditorgui.h
@@ -40,7 +40,7 @@ class KDE_EXPORT KRegExpEditorGUI :public TQWidget, public KRegExpEditorInterfa
TQ_OBJECT
TQ_PROPERTY( TQString regexp READ regExp WRITE setRegExp )
public:
- KRegExpEditorGUI( TQWidget *tqparent, const char *name = 0,
+ KRegExpEditorGUI( TQWidget *parent, const char *name = 0,
const TQStringList & = TQStringList() );
virtual TQString regExp() const;
@@ -70,7 +70,7 @@ class KDE_EXPORT KRegExpEditorGUIDialog : public KDialogBase, public KRegExpEdit
TQ_OBJECT
TQ_PROPERTY( TQString regexp READ regExp WRITE setRegExp )
public:
- KRegExpEditorGUIDialog( TQWidget *tqparent, const char *name, const TQStringList &args );
+ KRegExpEditorGUIDialog( TQWidget *parent, const char *name, const TQStringList &args );
virtual TQString regExp() const;
diff --git a/kregexpeditor/kregexpeditorprivate.cpp b/kregexpeditor/kregexpeditorprivate.cpp
index 2150293..5d9df7a 100644
--- a/kregexpeditor/kregexpeditorprivate.cpp
+++ b/kregexpeditor/kregexpeditorprivate.cpp
@@ -46,8 +46,8 @@
#include "verifybuttons.h"
#include <tqwhatsthis.h>
-KRegExpEditorPrivate::KRegExpEditorPrivate(TQWidget *tqparent, const char *name)
- : TQWidget(tqparent, name), _updating( false ), _autoVerify( true )
+KRegExpEditorPrivate::KRegExpEditorPrivate(TQWidget *parent, const char *name)
+ : TQWidget(parent, name), _updating( false ), _autoVerify( true )
{
setMinimumSize(730,300);
TQDockArea* area = new TQDockArea(Qt::Horizontal, TQDockArea::Normal, this );
diff --git a/kregexpeditor/kregexpeditorprivate.h b/kregexpeditor/kregexpeditorprivate.h
index effbdd7..ce7bc63 100644
--- a/kregexpeditor/kregexpeditorprivate.h
+++ b/kregexpeditor/kregexpeditorprivate.h
@@ -49,7 +49,7 @@ class KRegExpEditorPrivate :public TQWidget
TQ_OBJECT
public:
- KRegExpEditorPrivate( TQWidget *tqparent, const char *name = 0 );
+ KRegExpEditorPrivate( TQWidget *parent, const char *name = 0 );
TQString regexp();
void setMinimal( bool );
void setCaseSensitive( bool );
diff --git a/kregexpeditor/limitedcharlineedit.cpp b/kregexpeditor/limitedcharlineedit.cpp
index 7137b5e..59a6309 100644
--- a/kregexpeditor/limitedcharlineedit.cpp
+++ b/kregexpeditor/limitedcharlineedit.cpp
@@ -25,8 +25,8 @@
class Validator :public TQValidator
{
public:
- Validator( LimitedCharLineEdit::Mode mode, TQWidget* tqparent )
- :TQValidator( TQT_TQOBJECT(tqparent), "Validator" ), _mode(mode)
+ Validator( LimitedCharLineEdit::Mode mode, TQWidget* parent )
+ :TQValidator( TQT_TQOBJECT(parent), "Validator" ), _mode(mode)
{
}
@@ -56,8 +56,8 @@ void LimitedCharLineEdit::keyPressEvent ( TQKeyEvent *event )
focusNextPrevChild(true);
}
-LimitedCharLineEdit::LimitedCharLineEdit( Mode mode, TQWidget* tqparent, const char* name )
- :TQLineEdit( tqparent, name ), _mode(mode)
+LimitedCharLineEdit::LimitedCharLineEdit( Mode mode, TQWidget* parent, const char* name )
+ :TQLineEdit( parent, name ), _mode(mode)
{
if ( mode == NORMAL )
_count = 1;
diff --git a/kregexpeditor/limitedcharlineedit.h b/kregexpeditor/limitedcharlineedit.h
index 4b76250..98359a2 100644
--- a/kregexpeditor/limitedcharlineedit.h
+++ b/kregexpeditor/limitedcharlineedit.h
@@ -29,7 +29,7 @@ class LimitedCharLineEdit :public TQLineEdit
public:
enum Mode { NORMAL = 0, HEX = 1, OCT = 2 };
- LimitedCharLineEdit(Mode mode, TQWidget* tqparent, const char *name = 0);
+ LimitedCharLineEdit(Mode mode, TQWidget* parent, const char *name = 0);
protected:
virtual void keyPressEvent ( TQKeyEvent * );
diff --git a/kregexpeditor/lookaheadwidget.cpp b/kregexpeditor/lookaheadwidget.cpp
index 95e9c5c..c5dc700 100644
--- a/kregexpeditor/lookaheadwidget.cpp
+++ b/kregexpeditor/lookaheadwidget.cpp
@@ -28,16 +28,16 @@
#include "concwidget.h"
#include <tqpainter.h>
-LookAheadWidget::LookAheadWidget( RegExpEditorWindow* editorWindow, RegExpType tp, TQWidget* tqparent, const char* name )
- :SingleContainerWidget(editorWindow, tqparent, name ? name : "LookAheadWidget" ), _tp(tp)
+LookAheadWidget::LookAheadWidget( RegExpEditorWindow* editorWindow, RegExpType tp, TQWidget* parent, const char* name )
+ :SingleContainerWidget(editorWindow, parent, name ? name : "LookAheadWidget" ), _tp(tp)
{
_child = new ConcWidget( editorWindow, this );
init();
}
LookAheadWidget::LookAheadWidget( LookAheadRegExp* regexp, RegExpEditorWindow* editorWindow, RegExpType tp,
- TQWidget* tqparent, const char* name )
- :SingleContainerWidget( editorWindow, tqparent, name ? name : "LookAheadWidget" ), _tp(tp)
+ TQWidget* parent, const char* name )
+ :SingleContainerWidget( editorWindow, parent, name ? name : "LookAheadWidget" ), _tp(tp)
{
RegExpWidget* child = WidgetFactory::createWidget( regexp->child(), editorWindow, this );
if ( ! (_child = dynamic_cast<ConcWidget*>( child ) ) )
diff --git a/kregexpeditor/lookaheadwidget.h b/kregexpeditor/lookaheadwidget.h
index e5825b8..302090a 100644
--- a/kregexpeditor/lookaheadwidget.h
+++ b/kregexpeditor/lookaheadwidget.h
@@ -26,9 +26,9 @@ class LookAheadWidget :public SingleContainerWidget
Q_OBJECT
TQ_OBJECT
public:
- LookAheadWidget( RegExpEditorWindow* editorWindow, RegExpType tp, TQWidget* tqparent, const char* name = 0 );
+ LookAheadWidget( RegExpEditorWindow* editorWindow, RegExpType tp, TQWidget* parent, const char* name = 0 );
LookAheadWidget( LookAheadRegExp* regexp, RegExpEditorWindow* editorWindow, RegExpType tp,
- TQWidget* tqparent, const char* name = 0);
+ TQWidget* parent, const char* name = 0);
virtual RegExp* regExp() const;
virtual RegExpType type() const { return _tp; }
diff --git a/kregexpeditor/multicontainerwidget.h b/kregexpeditor/multicontainerwidget.h
index 8194eb1..560baa0 100644
--- a/kregexpeditor/multicontainerwidget.h
+++ b/kregexpeditor/multicontainerwidget.h
@@ -27,7 +27,7 @@
class MultiContainerWidget :public RegExpWidget
{
public:
- MultiContainerWidget( RegExpEditorWindow* editorWindow, TQWidget* tqparent = 0,
+ MultiContainerWidget( RegExpEditorWindow* editorWindow, TQWidget* parent = 0,
const char* name = 0);
virtual bool hasSelection() const;
virtual void clearSelection();
diff --git a/kregexpeditor/qt-only/compat.cpp b/kregexpeditor/qt-only/compat.cpp
index 528099e..a7a5d12 100644
--- a/kregexpeditor/qt-only/compat.cpp
+++ b/kregexpeditor/qt-only/compat.cpp
@@ -27,16 +27,16 @@ TQString i18n( const TQString& a, const TQString& b) {
}
KDialogBase::KDialogBase( int /*dialogFace*/, const TQString &caption, int buttonMask,
- ButtonCode defaultButton, TQWidget *tqparent, const char *name,
+ ButtonCode defaultButton, TQWidget *parent, const char *name,
bool modal )
- :TQDialog( tqparent, name, modal )
+ :TQDialog( parent, name, modal )
{
init( buttonMask, defaultButton, caption );
}
-KDialogBase::KDialogBase( TQWidget* tqparent, const char* name, bool modal,
+KDialogBase::KDialogBase( TQWidget* parent, const char* name, bool modal,
const TQString& caption, int buttonMask )
- : TQDialog( tqparent, name, modal )
+ : TQDialog( parent, name, modal )
{
init( buttonMask, Ok, caption );
}
@@ -92,24 +92,24 @@ void KDialogBase::slotCancel()
emit finished();
}
-int KMessageBox::warningYesNo(TQWidget *tqparent, const TQString &text, const TQString &caption )
+int KMessageBox::warningYesNo(TQWidget *parent, const TQString &text, const TQString &caption )
{
- int code = warning( tqparent, caption, text, tr("No"), tr("Yes") );
+ int code = warning( parent, caption, text, tr("No"), tr("Yes") );
if ( code == 0 )
return Yes;
else
return No;
}
-int KMessageBox::information( TQWidget* tqparent, const TQString& text, const TQString& caption,
+int KMessageBox::information( TQWidget* parent, const TQString& text, const TQString& caption,
const TQString& /*dontShowAgainName*/ )
{
- return TQMessageBox::information( tqparent, caption, text );
+ return TQMessageBox::information( parent, caption, text );
}
-int KMessageBox::sorry( TQWidget* tqparent, const TQString& text, const TQString& caption )
+int KMessageBox::sorry( TQWidget* parent, const TQString& text, const TQString& caption )
{
- return TQMessageBox::information( tqparent, caption, text );
+ return TQMessageBox::information( parent, caption, text );
}
diff --git a/kregexpeditor/qt-only/compat.h b/kregexpeditor/qt-only/compat.h
index f09cbbf..cd3d10f 100644
--- a/kregexpeditor/qt-only/compat.h
+++ b/kregexpeditor/qt-only/compat.h
@@ -45,9 +45,9 @@ public:
KDialogBase ( int dialogFace, const TQString &caption, int buttonMask,
ButtonCode defaultButton,
- TQWidget *tqparent=0, const char *name=0, bool modal=true );
+ TQWidget *parent=0, const char *name=0, bool modal=true );
- KDialogBase( TQWidget* tqparent, const char* name = 0, bool modal = true,
+ KDialogBase( TQWidget* parent, const char* name = 0, bool modal = true,
const TQString& caption = TQString(),
int buttonMask = 0 );
@@ -76,11 +76,11 @@ class KMessageBox :public TQMessageBox
TQ_OBJECT
public:
enum ButtonCode { Ok = 1, Cancel = 2, Yes = 3, No = 4, Continue = 5 };
- static int warningYesNo (TQWidget *tqparent, const TQString &text,
+ static int warningYesNo (TQWidget *parent, const TQString &text,
const TQString &caption = TQString() );
- static int information( TQWidget* tqparent, const TQString& text, const TQString& caption = TQString(),
+ static int information( TQWidget* parent, const TQString& text, const TQString& caption = TQString(),
const TQString& /*dontShowAgainName*/ = TQString() );
- static int sorry( TQWidget* tqparent, const TQString& text, const TQString& caption = TQString() );
+ static int sorry( TQWidget* parent, const TQString& text, const TQString& caption = TQString() );
};
#endif /* COMPAT_H */
diff --git a/kregexpeditor/regexp.cpp b/kregexpeditor/regexp.cpp
index c5961a3..cb94e84 100644
--- a/kregexpeditor/regexp.cpp
+++ b/kregexpeditor/regexp.cpp
@@ -49,9 +49,9 @@ void RegExp::removeChild( RegExp* child )
}
}
-void RegExp::setParent( RegExp* tqparent )
+void RegExp::setParent( RegExp* parent )
{
- _parent = tqparent;
+ _parent = parent;
}
RegExp* RegExp::readRegExp( TQDomElement top, const TQString& version )
diff --git a/kregexpeditor/regexp.h b/kregexpeditor/regexp.h
index ba828bb..9e0b384 100644
--- a/kregexpeditor/regexp.h
+++ b/kregexpeditor/regexp.h
@@ -44,7 +44,7 @@ public:
void addChild( RegExp* child );
void removeChild( RegExp* child );
- void setParent( RegExp* tqparent );
+ void setParent( RegExp* parent );
RegExp* clone() const;
virtual bool operator==( const RegExp& other ) const { return ( type() == other.type() ); }
diff --git a/kregexpeditor/regexpbuttons.cpp b/kregexpeditor/regexpbuttons.cpp
index f854f21..abbfb38 100644
--- a/kregexpeditor/regexpbuttons.cpp
+++ b/kregexpeditor/regexpbuttons.cpp
@@ -34,8 +34,8 @@
#include <tqsignalmapper.h>
#include "regexpconverter.h"
-RegExpButtons::RegExpButtons( TQWidget *tqparent, const char *name )
- : TQDockWindow( TQDockWindow::InDock, tqparent, name), _keepMode(false)
+RegExpButtons::RegExpButtons( TQWidget *parent, const char *name )
+ : TQDockWindow( TQDockWindow::InDock, parent, name), _keepMode(false)
{
TQBoxLayout *tqlayout = boxLayout();
diff --git a/kregexpeditor/regexpbuttons.h b/kregexpeditor/regexpbuttons.h
index 6219422..5cdbba0 100644
--- a/kregexpeditor/regexpbuttons.h
+++ b/kregexpeditor/regexpbuttons.h
@@ -32,7 +32,7 @@ class RegExpButtons :public TQDockWindow
TQ_OBJECT
public:
- RegExpButtons( TQWidget *tqparent, const char *name = 0 );
+ RegExpButtons( TQWidget *parent, const char *name = 0 );
void setFeatures( int features );
protected:
diff --git a/kregexpeditor/regexpwidget.h b/kregexpeditor/regexpwidget.h
index 0d65b8a..2fd455a 100644
--- a/kregexpeditor/regexpwidget.h
+++ b/kregexpeditor/regexpwidget.h
@@ -35,14 +35,14 @@ Q_OBJECT
TQ_OBJECT
public:
- RegExpWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ RegExpWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *label = 0);
/*======================================================================
Construction, child management
======================================================================*/
/**
- Add `child' to the tqparent of this widget in place of `accepter'
+ Add `child' to the parent of this widget in place of `accepter'
This method only applies to container widgets (see @ref
SingleContainerWidget, and @ref MultiContainerWidget).
*/
@@ -91,7 +91,7 @@ public:
/**
Update selection information for this widget.
- @param parentSelected indicates whether the tqparent is selected.
+ @param parentSelected indicates whether the parent is selected.
@return true if the selection state has changed for the widget since
the last time the widget was painted. `tqrepaint' is invoked on the widget if
selection state is changed, to ensure that selection is visible.
diff --git a/kregexpeditor/repeatwidget.cpp b/kregexpeditor/repeatwidget.cpp
index e284895..86f87f9 100644
--- a/kregexpeditor/repeatwidget.cpp
+++ b/kregexpeditor/repeatwidget.cpp
@@ -35,17 +35,17 @@
#include <tqvbuttongroup.h>
#include "kwidgetstreamer.h"
-RepeatWidget::RepeatWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+RepeatWidget::RepeatWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- : SingleContainerWidget(editorWindow, tqparent, name ? name : "RepeatWidget")
+ : SingleContainerWidget(editorWindow, parent, name ? name : "RepeatWidget")
{
_child = new ConcWidget(editorWindow, this);
init();
}
RepeatWidget::RepeatWidget( RepeatRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name )
- :SingleContainerWidget( editorWindow, tqparent, name )
+ TQWidget* parent, const char* name )
+ :SingleContainerWidget( editorWindow, parent, name )
{
init();
RegExpWidget* child = WidgetFactory::createWidget( regexp->child(), editorWindow, this );
@@ -167,8 +167,8 @@ int RepeatWidget::edit()
}
//--------------------------------------------------------------------------------
-RepeatRangeWindow::RepeatRangeWindow( TQWidget* tqparent, const char* name )
- : TQVBox( tqparent, name ? name : "RepeatRangeWindow" )
+RepeatRangeWindow::RepeatRangeWindow( TQWidget* parent, const char* name )
+ : TQVBox( parent, name ? name : "RepeatRangeWindow" )
{
setSpacing( 6 );
@@ -218,14 +218,14 @@ RepeatRangeWindow::RepeatRangeWindow( TQWidget* tqparent, const char* name )
}
-void RepeatRangeWindow::createLine( TQWidget* tqparent, TQString text, TQSpinBox** spin, REPEATTYPE tp )
+void RepeatRangeWindow::createLine( TQWidget* parent, TQString text, TQSpinBox** spin, REPEATTYPE tp )
{
- TQRadioButton* radioBut = new TQRadioButton(text, tqparent);
- *spin = new TQSpinBox( 1, 999, 1, tqparent);
+ TQRadioButton* radioBut = new TQRadioButton(text, parent);
+ *spin = new TQSpinBox( 1, 999, 1, parent);
(*spin)->setValue(1);
- (void) new TQLabel(i18n("time(s)"), tqparent);
+ (void) new TQLabel(i18n("time(s)"), parent);
_group->insert(radioBut, tp);
}
diff --git a/kregexpeditor/repeatwidget.h b/kregexpeditor/repeatwidget.h
index 14b3dec..8911461 100644
--- a/kregexpeditor/repeatwidget.h
+++ b/kregexpeditor/repeatwidget.h
@@ -38,7 +38,7 @@ Q_OBJECT
public:
enum REPEATTYPE {ANY, ATLEAST, ATMOST, EXACTLY, MINMAX};
- RepeatRangeWindow( TQWidget* tqparent, const char* name = 0 );
+ RepeatRangeWindow( TQWidget* parent, const char* name = 0 );
TQString text();
int min();
int max();
@@ -51,7 +51,7 @@ protected slots:
private:
- void createLine( TQWidget* tqparent, TQString text, TQSpinBox** spin, REPEATTYPE tp );
+ void createLine( TQWidget* parent, TQString text, TQSpinBox** spin, REPEATTYPE tp );
TQSpinBox* _leastTimes;
TQSpinBox* _mostTimes;
@@ -75,10 +75,10 @@ Q_OBJECT
TQ_OBJECT
public:
- RepeatWidget( RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ RepeatWidget( RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name = 0);
RepeatWidget( RepeatRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name = 0);
+ TQWidget* parent, const char* name = 0);
void init();
virtual TQSize tqsizeHint() const;
virtual RegExp* regExp() const;
diff --git a/kregexpeditor/scrollededitorwindow.cpp b/kregexpeditor/scrollededitorwindow.cpp
index cd88321..b14261c 100644
--- a/kregexpeditor/scrollededitorwindow.cpp
+++ b/kregexpeditor/scrollededitorwindow.cpp
@@ -22,8 +22,8 @@
#include "scrollededitorwindow.h"
#include "editorwindow.h"
-RegExpScrolledEditorWindow::RegExpScrolledEditorWindow( TQWidget* tqparent, const char* name)
- : TQWidget(tqparent, name)
+RegExpScrolledEditorWindow::RegExpScrolledEditorWindow( TQWidget* parent, const char* name)
+ : TQWidget(parent, name)
{
_scrollView = new TQScrollView( this );
_editorWindow = new RegExpEditorWindow( _scrollView->viewport());
diff --git a/kregexpeditor/scrollededitorwindow.h b/kregexpeditor/scrollededitorwindow.h
index e49940e..b404cee 100644
--- a/kregexpeditor/scrollededitorwindow.h
+++ b/kregexpeditor/scrollededitorwindow.h
@@ -32,7 +32,7 @@ class RegExpScrolledEditorWindow :public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- RegExpScrolledEditorWindow( TQWidget *tqparent = 0, const char* name = 0);
+ RegExpScrolledEditorWindow( TQWidget *parent = 0, const char* name = 0);
RegExp* regExp();
private:
diff --git a/kregexpeditor/selectablelineedit.cpp b/kregexpeditor/selectablelineedit.cpp
index c0344e2..ac42c83 100644
--- a/kregexpeditor/selectablelineedit.cpp
+++ b/kregexpeditor/selectablelineedit.cpp
@@ -22,8 +22,8 @@
#include "selectablelineedit.h"
-SelectableLineEdit::SelectableLineEdit( RegExpWidget* owner, TQWidget* tqparent, const char* name)
- : TQLineEdit( tqparent, name ), _owner(owner)
+SelectableLineEdit::SelectableLineEdit( RegExpWidget* owner, TQWidget* parent, const char* name)
+ : TQLineEdit( parent, name ), _owner(owner)
{
connect( this, TQT_SIGNAL( textChanged( const TQString & ) ), this,
TQT_SLOT( slotKeyPressed() ) );
diff --git a/kregexpeditor/selectablelineedit.h b/kregexpeditor/selectablelineedit.h
index 068aabc..7fb7ad7 100644
--- a/kregexpeditor/selectablelineedit.h
+++ b/kregexpeditor/selectablelineedit.h
@@ -37,7 +37,7 @@ Q_OBJECT
TQ_OBJECT
public:
- SelectableLineEdit( RegExpWidget* owner, TQWidget* tqparent = 0, const char* name = 0);
+ SelectableLineEdit( RegExpWidget* owner, TQWidget* parent = 0, const char* name = 0);
void setSelected( bool selected );
virtual TQSize tqsizeHint() const;
diff --git a/kregexpeditor/singlecontainerwidget.cpp b/kregexpeditor/singlecontainerwidget.cpp
index bfa90b9..2413236 100644
--- a/kregexpeditor/singlecontainerwidget.cpp
+++ b/kregexpeditor/singlecontainerwidget.cpp
@@ -23,8 +23,8 @@
#include "concwidget.h"
SingleContainerWidget::SingleContainerWidget(RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name)
- : RegExpWidget( editorWindow, tqparent, name )
+ TQWidget* parent, const char* name)
+ : RegExpWidget( editorWindow, parent, name )
{
}
diff --git a/kregexpeditor/singlecontainerwidget.h b/kregexpeditor/singlecontainerwidget.h
index 9b61ecf..3e6768a 100644
--- a/kregexpeditor/singlecontainerwidget.h
+++ b/kregexpeditor/singlecontainerwidget.h
@@ -28,7 +28,7 @@ Q_OBJECT
TQ_OBJECT
public:
- SingleContainerWidget( RegExpEditorWindow* editorWindow, TQWidget* tqparent,
+ SingleContainerWidget( RegExpEditorWindow* editorWindow, TQWidget* parent,
const char* name = 0);
virtual bool updateSelection( bool parentSelected );
diff --git a/kregexpeditor/textwidget.h b/kregexpeditor/textwidget.h
index 1520808..71ccf9b 100644
--- a/kregexpeditor/textwidget.h
+++ b/kregexpeditor/textwidget.h
@@ -33,10 +33,10 @@ class TextWidget : public RegExpWidget
TQ_OBJECT
public:
- TextWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ TextWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name = 0);
TextWidget( TextRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name = 0);
+ TQWidget* parent, const char* name = 0);
virtual TQSize tqsizeHint() const;
virtual RegExp* regExp() const;
virtual RegExpType type() const { return TEXT; }
diff --git a/kregexpeditor/userdefinedregexps.cpp b/kregexpeditor/userdefinedregexps.cpp
index 723e81f..85dc96e 100644
--- a/kregexpeditor/userdefinedregexps.cpp
+++ b/kregexpeditor/userdefinedregexps.cpp
@@ -35,8 +35,8 @@
#include <tqlayout.h>
#include <tqlabel.h>
-UserDefinedRegExps::UserDefinedRegExps( TQWidget *tqparent, const char *name )
- : TQDockWindow( TQDockWindow::InDock, tqparent, name)
+UserDefinedRegExps::UserDefinedRegExps( TQWidget *parent, const char *name )
+ : TQDockWindow( TQDockWindow::InDock, parent, name)
{
TQWidget* top = new TQWidget( this );
TQVBoxLayout* lay = new TQVBoxLayout( top, 6 );
@@ -223,8 +223,8 @@ void UserDefinedRegExps::slotSelectNewAction()
slotUnSelect();
}
-WidgetWinItem::WidgetWinItem( TQString fileName, RegExp* regexp, bool usersRegExp, TQListViewItem* tqparent )
- :TQListViewItem( tqparent ), _regexp( regexp ), _usersRegExp ( usersRegExp )
+WidgetWinItem::WidgetWinItem( TQString fileName, RegExp* regexp, bool usersRegExp, TQListViewItem* parent )
+ :TQListViewItem( parent ), _regexp( regexp ), _usersRegExp ( usersRegExp )
{
int index = fileName.findRev(TQString::fromLocal8Bit(".regexp"));
_name = fileName.left(index);
diff --git a/kregexpeditor/userdefinedregexps.h b/kregexpeditor/userdefinedregexps.h
index e6062ca..0b01b81 100644
--- a/kregexpeditor/userdefinedregexps.h
+++ b/kregexpeditor/userdefinedregexps.h
@@ -31,7 +31,7 @@ Q_OBJECT
TQ_OBJECT
public:
- UserDefinedRegExps( TQWidget *tqparent, const char *name = 0 );
+ UserDefinedRegExps( TQWidget *parent, const char *name = 0 );
const TQPtrList<CompoundRegExp> regExps() const;
public slots:
@@ -57,7 +57,7 @@ private:
class WidgetWinItem :public TQListViewItem
{
public:
- WidgetWinItem( TQString name, RegExp* regexp, bool users, TQListViewItem* tqparent );
+ WidgetWinItem( TQString name, RegExp* regexp, bool users, TQListViewItem* parent );
static TQString path();
TQString fileName() const;
diff --git a/kregexpeditor/verifier.cpp b/kregexpeditor/verifier.cpp
index 00b75be..18e1be3 100644
--- a/kregexpeditor/verifier.cpp
+++ b/kregexpeditor/verifier.cpp
@@ -24,7 +24,7 @@
#include "verifier.h"
-Verifier::Verifier( TQWidget* tqparent, const char* name ) : TQTextEdit( tqparent, name )
+Verifier::Verifier( TQWidget* parent, const char* name ) : TQTextEdit( parent, name )
/* TQT_ANCHOR_DO_NOT_WORK: ,_current( 0 ) */
{
_highlighter = 0;
diff --git a/kregexpeditor/verifier.h b/kregexpeditor/verifier.h
index 4d204de..d1999d6 100644
--- a/kregexpeditor/verifier.h
+++ b/kregexpeditor/verifier.h
@@ -28,7 +28,7 @@ class Verifier :public TQTextEdit
Q_OBJECT
TQ_OBJECT
public:
- Verifier( TQWidget* tqparent, const char* name = 0 );
+ Verifier( TQWidget* parent, const char* name = 0 );
void setHighlighter( RegexpHighlighter* );
public slots:
diff --git a/kregexpeditor/verifybuttons.cpp b/kregexpeditor/verifybuttons.cpp
index 05b0fb7..675d3e6 100644
--- a/kregexpeditor/verifybuttons.cpp
+++ b/kregexpeditor/verifybuttons.cpp
@@ -39,8 +39,8 @@
#include <tqpopupmenu.h>
#include <tqaction.h>
-VerifyButtons::VerifyButtons( TQWidget* tqparent, const char* name )
- :TQDockWindow( TQDockWindow::InDock, tqparent, name ), _configMenu( 0 )
+VerifyButtons::VerifyButtons( TQWidget* parent, const char* name )
+ :TQDockWindow( TQDockWindow::InDock, parent, name ), _configMenu( 0 )
{
TQBoxLayout* tqlayout = boxLayout();
diff --git a/kregexpeditor/verifybuttons.h b/kregexpeditor/verifybuttons.h
index 1298573..90629c0 100644
--- a/kregexpeditor/verifybuttons.h
+++ b/kregexpeditor/verifybuttons.h
@@ -31,7 +31,7 @@ class VerifyButtons :public TQDockWindow
TQ_OBJECT
public:
- VerifyButtons( TQWidget* tqparent, const char* name );
+ VerifyButtons( TQWidget* parent, const char* name );
RegExpConverter* setSyntax( const TQString& );
void setAllowNonTQtSyntax( bool );
diff --git a/kregexpeditor/widgetfactory.cpp b/kregexpeditor/widgetfactory.cpp
index 4bbc2b9..9f167b2 100644
--- a/kregexpeditor/widgetfactory.cpp
+++ b/kregexpeditor/widgetfactory.cpp
@@ -46,35 +46,35 @@ bool WidgetFactory::isContainer( RegExpType tp )
return ( tp == REPEAT || tp == ALTN || tp == COMPOUND );
}
-RegExpWidget* WidgetFactory::createWidget( RegExpEditorWindow* win, TQWidget* tqparent,
+RegExpWidget* WidgetFactory::createWidget( RegExpEditorWindow* win, TQWidget* parent,
RegExpType type )
{
RegExpWidget* widget = 0;
switch (type) {
case TEXT:
- return new TextWidget( win, tqparent ); break;
+ return new TextWidget( win, parent ); break;
case ALTN:
- return new AltnWidget( win, tqparent ); break;
+ return new AltnWidget( win, parent ); break;
case DOT:
- return new AnyCharWidget( win, tqparent ); break;
+ return new AnyCharWidget( win, parent ); break;
case BEGLINE:
- return new BegLineWidget( win, tqparent ); break;
+ return new BegLineWidget( win, parent ); break;
case ENDLINE:
- return new EndLineWidget( win, tqparent ); break;
+ return new EndLineWidget( win, parent ); break;
case WORDBOUNDARY:
- return new WordBoundaryWidget( win, tqparent ); break;
+ return new WordBoundaryWidget( win, parent ); break;
case NONWORDBOUNDARY:
- return new NonWordBoundaryWidget( win, tqparent ); break;
+ return new NonWordBoundaryWidget( win, parent ); break;
case POSLOOKAHEAD:
case NEGLOOKAHEAD:
- return new LookAheadWidget( win, type, tqparent ); break;
+ return new LookAheadWidget( win, type, parent ); break;
case REPEAT:
- widget = new RepeatWidget( win, tqparent ); break;
+ widget = new RepeatWidget( win, parent ); break;
case CHARSET:
- widget = new CharactersWidget( win, tqparent ); break;
+ widget = new CharactersWidget( win, parent ); break;
case COMPOUND:
- widget = new CompoundWidget( win, tqparent ); break;
+ widget = new CompoundWidget( win, parent ); break;
default:
qFatal("It should not be possible to get here!");
return 0;
@@ -88,43 +88,43 @@ RegExpWidget* WidgetFactory::createWidget( RegExpEditorWindow* win, TQWidget* tq
}
RegExpWidget* WidgetFactory::createWidget( RegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent )
+ TQWidget* parent )
{
if ( regexp == 0 ) {
qFatal("%s:%d Regexp is 0", __FILE__, __LINE__ );
}
else if ( TextRegExp* reg = dynamic_cast<TextRegExp*>( regexp ) )
- return new TextWidget( reg, editorWindow, tqparent );
+ return new TextWidget( reg, editorWindow, parent );
else if ( TextRangeRegExp* reg = dynamic_cast<TextRangeRegExp*>( regexp ) )
- return new CharactersWidget( reg, editorWindow, tqparent );
+ return new CharactersWidget( reg, editorWindow, parent );
else if ( RepeatRegExp* reg = dynamic_cast<RepeatRegExp*>( regexp ) )
- return new RepeatWidget( reg, editorWindow, tqparent );
+ return new RepeatWidget( reg, editorWindow, parent );
else if ( LookAheadRegExp* reg = dynamic_cast<LookAheadRegExp*>( regexp ) ) {
if ( reg->lookAheadType() == LookAheadRegExp::POSITIVE )
- return new LookAheadWidget( reg, editorWindow, POSLOOKAHEAD, tqparent );
+ return new LookAheadWidget( reg, editorWindow, POSLOOKAHEAD, parent );
else
- return new LookAheadWidget( reg, editorWindow, NEGLOOKAHEAD, tqparent );
+ return new LookAheadWidget( reg, editorWindow, NEGLOOKAHEAD, parent );
}
else if ( ConcRegExp* reg = dynamic_cast<ConcRegExp*>( regexp ) )
- return new ConcWidget( reg, editorWindow, tqparent );
+ return new ConcWidget( reg, editorWindow, parent );
else if ( AltnRegExp* reg = dynamic_cast<AltnRegExp*>( regexp ) )
- return new AltnWidget( reg, editorWindow, tqparent );
+ return new AltnWidget( reg, editorWindow, parent );
else if ( PositionRegExp* reg = dynamic_cast<PositionRegExp*>( regexp ) ) {
switch ( reg->position() ) {
case PositionRegExp::BEGLINE:
- return new BegLineWidget( editorWindow, tqparent );
+ return new BegLineWidget( editorWindow, parent );
case PositionRegExp::ENDLINE:
- return new EndLineWidget( editorWindow, tqparent );
+ return new EndLineWidget( editorWindow, parent );
case PositionRegExp::WORDBOUNDARY:
- return new WordBoundaryWidget( editorWindow, tqparent );
+ return new WordBoundaryWidget( editorWindow, parent );
case PositionRegExp::NONWORDBOUNDARY:
- return new NonWordBoundaryWidget( editorWindow, tqparent );
+ return new NonWordBoundaryWidget( editorWindow, parent );
}
}
else if ( dynamic_cast<DotRegExp*>( regexp ) )
- return new AnyCharWidget( editorWindow, tqparent );
+ return new AnyCharWidget( editorWindow, parent );
else if ( CompoundRegExp* reg = dynamic_cast<CompoundRegExp*>( regexp ) )
- return new CompoundWidget( reg, editorWindow, tqparent );
+ return new CompoundWidget( reg, editorWindow, parent );
else {
qFatal("%s:%d Internal Error: Unknown RegExp type", __FILE__, __LINE__);
}
diff --git a/kregexpeditor/widgetfactory.h b/kregexpeditor/widgetfactory.h
index 836ee12..2ef7233 100644
--- a/kregexpeditor/widgetfactory.h
+++ b/kregexpeditor/widgetfactory.h
@@ -47,10 +47,10 @@ enum RegExpType {
class WidgetFactory
{
public:
- static RegExpWidget* createWidget( RegExpEditorWindow* editorWindow, TQWidget* tqparent,
+ static RegExpWidget* createWidget( RegExpEditorWindow* editorWindow, TQWidget* parent,
RegExpType type );
static RegExpWidget* createWidget( RegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent );
+ TQWidget* parent );
static RegExp* createRegExp( TQDomElement node, const TQString& version );
static RegExp* createRegExp( TQString str );
static bool isContainer( RegExpType );
diff --git a/kregexpeditor/zerowidgets.cpp b/kregexpeditor/zerowidgets.cpp
index ede99cb..eaf1aaf 100644
--- a/kregexpeditor/zerowidgets.cpp
+++ b/kregexpeditor/zerowidgets.cpp
@@ -31,8 +31,8 @@
// ZeroWidget
//--------------------------------------------------------------------------------
ZeroWidget::ZeroWidget(TQString txt, RegExpEditorWindow* editorWindow,
- TQWidget *tqparent, const char *name)
- : RegExpWidget(editorWindow, tqparent, name ? name : "ZeroWidget" )
+ TQWidget *parent, const char *name)
+ : RegExpWidget(editorWindow, parent, name ? name : "ZeroWidget" )
{
_text = txt;
}
@@ -70,9 +70,9 @@ void ZeroWidget::paintEvent( TQPaintEvent *e)
//--------------------------------------------------------------------------------
// AnyCharWidget
//--------------------------------------------------------------------------------
-AnyCharWidget::AnyCharWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+AnyCharWidget::AnyCharWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- : ZeroWidget(i18n("Any\nCharacter"), editorWindow, tqparent,
+ : ZeroWidget(i18n("Any\nCharacter"), editorWindow, parent,
name ? name : "AnyCharWidget")
{
}
@@ -86,9 +86,9 @@ RegExp* AnyCharWidget::regExp() const
//--------------------------------------------------------------------------------
// BegLineWidget
//--------------------------------------------------------------------------------
-BegLineWidget::BegLineWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+BegLineWidget::BegLineWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- : ZeroWidget(i18n("Line\nStart"), editorWindow, tqparent,
+ : ZeroWidget(i18n("Line\nStart"), editorWindow, parent,
name ? name : "BegLineWidget")
{
}
@@ -102,9 +102,9 @@ RegExp* BegLineWidget::regExp() const
//--------------------------------------------------------------------------------
// EndLineWidget
//--------------------------------------------------------------------------------
-EndLineWidget::EndLineWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+EndLineWidget::EndLineWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- : ZeroWidget(i18n("Line\nEnd"), editorWindow, tqparent, name)
+ : ZeroWidget(i18n("Line\nEnd"), editorWindow, parent, name)
{
}
@@ -116,9 +116,9 @@ RegExp* EndLineWidget::regExp() const
//--------------------------------------------------------------------------------
// WordBoundaryWidget
//--------------------------------------------------------------------------------
-WordBoundaryWidget::WordBoundaryWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+WordBoundaryWidget::WordBoundaryWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- : ZeroWidget(i18n("Word\nBoundary"), editorWindow, tqparent,
+ : ZeroWidget(i18n("Word\nBoundary"), editorWindow, parent,
name ? name : "WordBoundaryWidget" )
{
}
@@ -131,9 +131,9 @@ RegExp* WordBoundaryWidget::regExp() const
//--------------------------------------------------------------------------------
// NonWordBoundaryWidget
//--------------------------------------------------------------------------------
-NonWordBoundaryWidget::NonWordBoundaryWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+NonWordBoundaryWidget::NonWordBoundaryWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- : ZeroWidget(i18n("Non-word\nBoundary"), editorWindow, tqparent,
+ : ZeroWidget(i18n("Non-word\nBoundary"), editorWindow, parent,
name ? name : "NonWordBoundaryWidget" )
{
}
diff --git a/kregexpeditor/zerowidgets.h b/kregexpeditor/zerowidgets.h
index f418988..780f426 100644
--- a/kregexpeditor/zerowidgets.h
+++ b/kregexpeditor/zerowidgets.h
@@ -27,7 +27,7 @@
class ZeroWidget :public RegExpWidget
{
public:
- ZeroWidget(TQString text, RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ ZeroWidget(TQString text, RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name = 0);
virtual void addNewChild(DragAccepter *accepter, RegExpWidget *child);
virtual TQSize tqsizeHint() const;
@@ -51,7 +51,7 @@ private:
class AnyCharWidget :public ZeroWidget
{
public:
- AnyCharWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ AnyCharWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *label = 0);
virtual RegExp* regExp() const;
@@ -68,7 +68,7 @@ public:
class BegLineWidget : public ZeroWidget
{
public:
- BegLineWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ BegLineWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name = 0);
virtual RegExp* regExp() const;
virtual RegExpType type() const { return BEGLINE; }
@@ -84,7 +84,7 @@ public:
class EndLineWidget : public ZeroWidget
{
public:
- EndLineWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ EndLineWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name = 0);
virtual RegExp* regExp() const;
virtual RegExpType type() const { return ENDLINE; }
@@ -99,7 +99,7 @@ public:
class WordBoundaryWidget : public ZeroWidget
{
public:
- WordBoundaryWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ WordBoundaryWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name = 0);
virtual RegExp* regExp() const;
virtual RegExpType type() const { return WORDBOUNDARY; }
@@ -115,7 +115,7 @@ public:
class NonWordBoundaryWidget : public ZeroWidget
{
public:
- NonWordBoundaryWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+ NonWordBoundaryWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name = 0);
virtual RegExp* regExp() const;
virtual RegExpType type() const { return NONWORDBOUNDARY; }
diff --git a/kregexpeditor/characterswidget.cpp b/kregexpeditor/characterswidget.cpp
index 2656c2f..227f605 100644
--- a/kregexpeditor/characterswidget.cpp
+++ b/kregexpeditor/characterswidget.cpp
@@ -39,16 +39,16 @@
CharacterEdits* CharactersWidget::_configWindow = 0;
-CharactersWidget::CharactersWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+CharactersWidget::CharactersWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- : RegExpWidget(editorWindow, tqparent, name)
+ : RegExpWidget(editorWindow, parent, name)
{
_regexp = new TextRangeRegExp( false /* not used */);
}
CharactersWidget::CharactersWidget( TextRangeRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name )
- : RegExpWidget( editorWindow, tqparent, name )
+ TQWidget* parent, const char* name )
+ : RegExpWidget( editorWindow, parent, name )
{
_regexp = dynamic_cast<TextRangeRegExp*>( regexp->clone() );
Q_ASSERT( _regexp );
@@ -181,7 +181,7 @@ int CharactersWidget::edit()
{
if ( _configWindow == 0 ) {
TQApplication::setOverrideCursor( WaitCursor );
// No tqparent here, as this window should continue to exists.
_configWindow = new CharacterEdits( 0, "CharactersWidget::_configWindow" );
TQApplication::restoreOverrideCursor();
}
@@ -282,8 +282,8 @@ int CharacterEdits::exec( TextRangeRegExp* regexp )
}
-CharacterEdits::CharacterEdits( TQWidget *tqparent, const char *name)
- : KDialogBase( tqparent, name == 0 ? "CharacterEdits" : name, true,
+CharacterEdits::CharacterEdits( TQWidget *parent, const char *name)
+ : KDialogBase( parent, name == 0 ? "CharacterEdits" : name, true,
i18n("Specify Characters"),
KDialogBase::Ok | KDialogBase::Cancel)
{
@@ -377,8 +377,8 @@ void CharacterEdits::slotOK()
}
-SingleEntry::SingleEntry(TQWidget* tqparent, const char* name )
- :KMultiFormListBoxEntry( tqparent, name )
+SingleEntry::SingleEntry(TQWidget* parent, const char* name )
+ :KMultiFormListBoxEntry( parent, name )
{
TQHBoxLayout* tqlayout = new TQHBoxLayout( this, 3, 6 );
_selector = new CharSelector( this );
@@ -402,8 +402,8 @@ bool SingleEntry::isEmpty() const
}
-RangeEntry::RangeEntry(TQWidget* tqparent, const char* name )
- :KMultiFormListBoxEntry( tqparent, name )
+RangeEntry::RangeEntry(TQWidget* parent, const char* name )
+ :KMultiFormListBoxEntry( parent, name )
{
TQHBoxLayout* tqlayout = new TQHBoxLayout( this, 3, 6 );
@@ -181,7 +181,7 @@ int CharactersWidget::edit()
if ( _configWindow == 0 ) {
TQApplication::setOverrideCursor( WaitCursor );
- // No tqparent here, as this window should continue to exists.
+ // No parent here, as this window should continue to exists.
_configWindow = new CharacterEdits( 0, "CharactersWidget::_configWindow" );
TQApplication::restoreOverrideCursor();
diff --git a/kregexpeditor/dragaccepter.cpp b/kregexpeditor/dragaccepter.cpp
index 676c851..6bd049e 100644
--- a/kregexpeditor/dragaccepter.cpp
+++ b/kregexpeditor/dragaccepter.cpp
@@ -20,9 +20,9 @@
#include <tqpainter.h>
-DragAccepter::DragAccepter(RegExpEditorWindow* editorWindow, RegExpWidget *tqparent,
+DragAccepter::DragAccepter(RegExpEditorWindow* editorWindow, RegExpWidget *parent,
const char *name)
- : RegExpWidget(editorWindow, tqparent, name == 0 ? "dragaccepter" : name ),
+ : RegExpWidget(editorWindow, parent, name == 0 ? "dragaccepter" : name ),
_drawLine( false )
{
setAcceptDrops(TRUE);
@@ -68,7 +68,7 @@ void DragAccepter::mouseReleaseEvent( TQMouseEvent* event )
Q_ASSERT( elm );
- RegExpWidget *w = dynamic_cast<RegExpWidget*>(tqparent());
+ RegExpWidget *w = dynamic_cast<RegExpWidget*>(parent());
if (w)
w->addNewConcChild(this, elm);
_editorWindow->updateContent( this );
@@ -82,10 +82,10 @@ void DragAccepter::mouseReleaseEvent( TQMouseEvent* event )
}
else {
RegExpWidget *child = WidgetFactory::createWidget( _editorWindow,
- dynamic_cast<TQWidget*>(tqparent()),
+ dynamic_cast<TQWidget*>(parent()),
_editorWindow->insertType() );
if ( child ) {
- RegExpWidget *w = dynamic_cast<RegExpWidget*>(tqparent());
+ RegExpWidget *w = dynamic_cast<RegExpWidget*>(parent());
if (w)
w->addNewChild(this, child);
_editorWindow->updateContent( child );
@@ -107,7 +107,7 @@ void DragAccepter::dragEnterEvent(TQDragEnterEvent *event)
void DragAccepter::dropEvent(TQDropEvent *event)
{
// The widget will be reparent afterward or part of it will, so no need to give
// it a tqparent here.
RegExpWidget *newElm = RegExpWidgetDrag::decode( event, _editorWindow, 0 );
ConcWidget* elm;
if ( !(elm = dynamic_cast<ConcWidget*>( newElm ) ) ) {
@@ -116,10 +116,10 @@ void DragAccepter::dropEvent(TQDropEvent *event)
Q_ASSERT( elm );
- RegExpWidget *rew = dynamic_cast<RegExpWidget*>(tqparent());
+ RegExpWidget *rew = dynamic_cast<RegExpWidget*>(parent());
if (rew)
rew->addNewConcChild(this, elm);
- TQWidget *w = dynamic_cast<TQWidget*>(tqparent());
+ TQWidget *w = dynamic_cast<TQWidget*>(parent());
if (w)
w->update();
_editorWindow->updateContent( this );
@@ -107,7 +107,7 @@ void DragAccepter::dragEnterEvent(TQDragEnterEvent *event)
{
// The widget will be reparent afterward or part of it will, so no need to give
- // it a tqparent here.
+ // it a parent here.
RegExpWidget *newElm = RegExpWidgetDrag::decode( event, _editorWindow, 0 );
ConcWidget* elm;
diff --git a/kregexpeditor/multicontainerwidget.cpp b/kregexpeditor/multicontainerwidget.cpp
index 152f7a3..d8bef97 100644
--- a/kregexpeditor/multicontainerwidget.cpp
+++ b/kregexpeditor/multicontainerwidget.cpp
@@ -19,8 +19,8 @@
#include "dragaccepter.h"
MultiContainerWidget::MultiContainerWidget( RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name)
- :RegExpWidget( editorWindow, tqparent, name )
+ TQWidget* parent, const char* name)
+ :RegExpWidget( editorWindow, parent, name )
{
}
@@ -150,7 +150,7 @@ bool MultiContainerWidget::updateSelection(bool parentSelected)
RegExpWidget* child = _tqchildren.at(k);
bool select;
if ( k == 0 || k == (int)_tqchildren.count()-1) {
// The elements at the border is only selected if the tqparent is selected.
select = _isSelected;
}
else {
@@ -150,7 +150,7 @@ bool MultiContainerWidget::updateSelection(bool parentSelected)
bool select;
if ( k == 0 || k == (int)_tqchildren.count()-1) {
- // The elements at the border is only selected if the tqparent is selected.
+ // The elements at the border is only selected if the parent is selected.
select = _isSelected;
}
diff --git a/kregexpeditor/regexpwidget.cpp b/kregexpeditor/regexpwidget.cpp
index 53e8540..c164c51 100644
--- a/kregexpeditor/regexpwidget.cpp
+++ b/kregexpeditor/regexpwidget.cpp
@@ -33,9 +33,9 @@ const int RegExpWidget::pw = 1;
const int RegExpWidget::bdSize = 5;
const int RegExpWidget::space = 5;
-RegExpWidget::RegExpWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+RegExpWidget::RegExpWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- : TQWidget(tqparent, name ? name : "RegExpWidget", WNoMousePropagation ),
+ : TQWidget(parent, name ? name : "RegExpWidget", WNoMousePropagation ),
_editorWindow( editorWindow ), _isSelected( false ), _isToplevel( false )
{
}
@@ -136,7 +136,7 @@ void RegExpWidget::mousePressEvent ( TQMouseEvent* event )
}
// currently (TQt3.0) it seems like qt do not accept that the accept flag is set,
// and thus sends the event to the tqparent - given that the following line is in.
// It doesn't make any change to leave it out.
// 25 Oct. 2001 19:03 -- Jesper K. Pedersen
// TQWidget::mousePressEvent( event );
@@ -136,7 +136,7 @@ void RegExpWidget::mousePressEvent ( TQMouseEvent* event )
}
// currently (TQt3.0) it seems like qt do not accept that the accept flag is set,
- // and thus sends the event to the tqparent - given that the following line is in.
+ // and thus sends the event to the parent - given that the following line is in.
// It doesn't make any change to leave it out.
// 25 Oct. 2001 19:03 -- Jesper K. Pedersen
diff --git a/kregexpeditor/textwidget.cpp b/kregexpeditor/textwidget.cpp
index 1095749..99a77e1 100644
--- a/kregexpeditor/textwidget.cpp
+++ b/kregexpeditor/textwidget.cpp
@@ -24,16 +24,16 @@
#include "selectablelineedit.h"
#include <tqlayout.h>
-TextWidget::TextWidget(RegExpEditorWindow* editorWindow, TQWidget *tqparent,
+TextWidget::TextWidget(RegExpEditorWindow* editorWindow, TQWidget *parent,
const char *name)
- :RegExpWidget(editorWindow, tqparent, name)
+ :RegExpWidget(editorWindow, parent, name)
{
init( TQString::fromLocal8Bit("") );
}
TextWidget::TextWidget( TextRegExp* regexp, RegExpEditorWindow* editorWindow,
- TQWidget* tqparent, const char* name )
- : RegExpWidget( editorWindow, tqparent, name )
+ TQWidget* parent, const char* name )
+ : RegExpWidget( editorWindow, parent, name )
{
init(regexp->text());
}
@@ -56,11 +56,11 @@ void TextWidget::init( const TQString& txt )
void TextWidget::slotUpdate()
{
// I need to force the tqparent to tqrepaint, as the size change of this
// widget may not be enough for the tqparent to change size, and in that
// case the tqparent would not tqrepaint, and the text widget would not be
// resized.
- TQWidget *p = TQT_TQWIDGET(tqparent());
+ TQWidget *p = TQT_TQWIDGET(parent());
if (p)
p->tqrepaint();
_editorWindow->updateContent( this );
@@ -56,11 +56,11 @@ void TextWidget::init( const TQString& txt )
void TextWidget::slotUpdate()
{
- // I need to force the tqparent to tqrepaint, as the size change of this
- // widget may not be enough for the tqparent to change size, and in that
- // case the tqparent would not tqrepaint, and the text widget would not be
+ // I need to force the parent to tqrepaint, as the size change of this
+ // widget may not be enough for the parent to change size, and in that
+ // case the parent would not tqrepaint, and the text widget would not be
// resized.